//#include "metalShaderTypes.h"

typedef struct
{
	int direction;
} fxVars;

vertex vertexOut vertexFunc(uint vertexID [[ vertex_id ]],const device txShaderVers* in[[ buffer(0) ]],constant txShaderUniforms& uniforms[[ buffer(3) ]],constant fxVars& vars[[ buffer(2)]])
{
    vertexOut out;

    out.position=in[vertexID].pos*uniforms.worldViewProj;

    out.tex1=in[vertexID].tex1;
	out.tex2=in[vertexID].tex2;
	out.texMask=in[vertexID].texMask;
	out.normPos=in[vertexID].pos.xy*vec2(.5,.5f)+vec2(.5,.5);
    return out;
}

vec2 offset(float scale,float progress, float x, float theta)
{
    float shifty = 0.023*scale*cos(10.0*(progress+x));
    return vec2(0, shifty);
}

fragment float4 fragmentFunc(vertexOut in [[stage_in]]
							 ,texture2d<half> inputTex0 [[ texture(0) ]]
							 ,texture2d<half> inputTex1 [[ texture(1) ]]
							 ,texture2d<half> inputTexMask [[ texture(2) ]]
							 ,constant txShaderUniforms& u[[ buffer(2) ]]
							 ,constant fxVars& vars[[ buffer(1)]])
{
	vec4 texColor=tex(inputTex0,in.tex1)*u.baseAlpha;
	vec4 colorA=mix(vec4(0,0,0,0),texColor,u.mix);
	vec4 colorB=mix(texColor,vec4(0,0,0,0),u.mix);
	
	float diffIn;
	float diffOut;
	
    switch(vars.direction)
    {
        case 0: //top left
        {
            float tp=u.transitionProgress*1.1;
            
            diffIn=tp-(in.tex1.x+in.tex1.y)*.5;
            diffOut=(in.tex1.x+in.tex1.y)*.5-(tp-.1);
            break;
        }
        case 1: //top center
        {
            float tp=u.transitionProgress*1.1;
            
            diffIn=tp-in.tex1.y;
            diffOut=in.tex1.y-(tp-.1);
            break;
        }
        case 2: //top right
        {
            float tp=u.transitionProgress*1.1;
            diffIn=tp-((1.0-in.tex1.x)+in.tex1.y)*.5;
            diffOut=((1.0-in.tex1.x)+in.tex1.y)*.5-(tp-.1);
            break;
            break;
        }
        case 3: //middle left
        {
            float tp=u.transitionProgress*1.1;
            
            diffIn=tp-in.tex1.x;
            diffOut=in.tex1.x-(tp-.1);
            break;
        }
        case 4: //middle center - not used
        {
            float tp=u.transitionProgress*1.1;
            
            diffIn=tp-in.tex1.x;
            diffOut=in.tex1.x-(tp-.1);
            break;
        }
        case 5: //middle right
        {
            float tp=(1.0-u.transitionProgress)*1.1;
            
            diffIn=in.tex1.x-(tp-.1);
            diffOut=tp-in.tex1.x;
            break;
        }
        case 6: //bottom left
        {
            float tp=u.transitionProgress*1.1;
            
            diffIn=tp-(in.tex1.x+(1.0-in.tex1.y))*.5;
            diffOut=(in.tex1.x+(1.0-in.tex1.y))*.5-(tp-.1);
            break;
        }
        case 7: //bottom center
        {
            float tp=(1.0-u.transitionProgress)*1.1;
            
            diffIn=in.tex1.y-(tp-.1);
            diffOut=tp-in.tex1.y;
            break;
        }
        case 8: //bottom right
        {
            float tp=u.transitionProgress*1.1;
            vec2 tmp=1.0-in.tex1;
            diffIn=tp-(tmp.x+tmp.y)*.5;
            diffOut=(tmp.x+tmp.y)*.5-(tp-.1);
        }
    }
	
	diffIn=clamp(diffIn*10.0,0.0,1.0);
	diffOut=clamp(diffOut*10.0,0.0,1.0);
	float4 outColor=colorA*diffIn+colorB*diffOut;;
	
#ifdef USE_MASK
	outColor.a*=float(inputTexMask.sample(linearSampler,in.texMask).a);
#endif

	return outColor;
}
